"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const d3 = require("d3");
const parser_1 = require("../../parser");
const generateTreeData = (start, pkg) => {
    const treeData = {
        name: start,
        children: [],
    };
    parser_1.makeChain(treeData, pkg);
    return treeData;
};
exports.generateState = (currentKey, pkg) => {
    const treeData = generateTreeData(currentKey, pkg);
    const data = d3.hierarchy(treeData);
    const root = d3.tree()(data);
    const nodes = root.descendants();
    const links = root.links();
    return {
        npmUrl: "https://www.npmjs.com/package/npm-run-script-chain",
        currentKey,
        pkg,
        scripts: Object.keys(pkg.scripts),
        scale: {
            x: 200,
            y: 400,
            offsetX: 0,
            offsetY: 100,
        },
        radius: 5,
        offset: 1,
        nodes,
        links,
    };
};
exports.appReducer = (state, action) => {
    switch (action.type) {
        case "UPDATE_KEY": {
            const newState = exports.generateState(action.currentKey, state.pkg);
            return newState;
        }
        default:
            return state;
    }
};
//# sourceMappingURL=Reducer.js.map